@@ -1,14 +1,15 @@
-/* aewm - a minimalist X11 window mananager. vim:noet:sw=4:ts=4
- * Copyright 1998-2001 Decklin Foster <decklin@red-bean.com>
+/* aewm - a minimalist X11 window mananager. vim:sw=4:ts=4:et
+ * Copyright 1998-2003 Decklin Foster <decklin@red-bean.com>
  * This program is free software; see LICENSE for details. */
 
 #ifndef AEWM_CLIENTS_AECLIENTS_H
 #define AEWM_CLIENTS_AECLIENTS_H
 
+#include <stdlib.h>
 #include "common.h"
 
 #define DEF_RC  "/etc/X11/aewm/clientsrc"
-#define SPACING 4
+#define SPACING 3
 
 typedef void *menu_t;
 
