@@ -1,16 +1,16 @@
-/* aewm - a minimalist X11 window mananager. vim:noet:sw=4:ts=4
- * Copyright 1998-2001 Decklin Foster <decklin@red-bean.com>
+/* aewm - a minimalist X11 window mananager. vim:sw=4:ts=4:et
+ * Copyright 1998-2003 Decklin Foster <decklin@red-bean.com>
  * This program is free software; see LICENSE for details. */
 
 #ifndef AEWM_CLIENTS_PANEL_H
 #define AEWM_CLIENTS_PANEL_H
 
+#include <signal.h>
 #include <X11/X.h>
-
-extern Atom gnome_pda;
+#include "gnome-pda.h"
 
 extern void sig_handler(int);
-extern void set_gnome_pda(int, int, int, int);
+extern void set_gnome_pda(deskarea_t *);
 extern void clear_gnome_pda(void);
 
 #endif /* AEWM_CLIENTS_PANEL_H */
